@@ -1,10 +1,10 @@
 package Net::GPSD3::Return::SKY;
 use strict;
 use warnings;
-use base qw{Net::GPSD3::Return::Unknown};
+use base qw{Net::GPSD3::Return::Unknown::Timestamp};
 use DateTime;
 
-our $VERSION='0.07';
+our $VERSION='0.12';
 
 =head1 NAME
 
@@ -18,6 +18,8 @@ Provides a Perl object interface to the SKY object returned by the GPSD daemon.
 
 An example JSON object:
 
+=head3 Protcol 3.1 versions
+
   {
     "class":"SKY",
     "tag":"MID4",
@@ -39,6 +41,35 @@ An example JSON object:
       ]
   }
 
+=head3 Protcol 3.4 versions
+
+  {
+    "class":"SKY",
+    "tag":"0x0120",
+    "device":"/dev/cuaU0",
+    "xdop":0.58,
+    "ydop":0.96,
+    "vdop":1.92,
+    "tdop":1.14,
+    "hdop":1.90,
+    "gdop":2.93,
+    "pdop":2.70,
+    "satellites":[
+      {"PRN":17,"el":76,"az":174,"ss":34,"used":true},
+      {"PRN":28,"el":57,"az":38,"ss":30,"used":false},
+      {"PRN":27,"el":22,"az":314,"ss":18,"used":true},
+      {"PRN":7,"el":15,"az":127,"ss":29,"used":true},
+      {"PRN":15,"el":31,"az":297,"ss":27,"used":true},
+      {"PRN":11,"el":18,"az":54,"ss":28,"used":false},
+      {"PRN":24,"el":18,"az":63,"ss":29,"used":false},
+      {"PRN":9,"el":4,"az":313,"ss":18,"used":false},
+      {"PRN":8,"el":45,"az":117,"ss":33,"used":true},
+      {"PRN":26,"el":49,"az":245,"ss":37,"used":true},
+      {"PRN":4,"el":5,"az":170,"ss":17,"used":false},
+      {"PRN":138,"el":44,"az":157,"ss":40,"used":true}
+    ]
+  }
+
 =head1 METHODS PROPERTIES
 
 =head2 class
@@ -67,35 +98,10 @@ sub tag {shift->{"tag"}};
 
 =head2 time
 
-=cut
-
-sub time {shift->{"time"}};
+=head2 timestamp
 
 =head2 datetime
 
-Returns a L<DateTime> object
-
-=cut
-
-sub datetime {
-  my $self=shift;
-  unless (defined($self->{"datetime"})) {
-    $self->{"datetime"}=DateTime->from_epoch(epoch=>$self->time);
-  }
-  return $self->{"datetime"};
-}
-
-=head2 strftime
-
-Returns the formatted datetime
-
-=cut
-
-sub strftime {
-  my $self=shift;
-  return $self->datetime->strftime($self->parent->strftime);
-}
-
 =head2 reported
 
 Count of satellites in view
@@ -104,11 +110,8 @@ Count of satellites in view
 
 sub reported {
   my $self=shift;
-  unless (defined($self->{"reported"})) {
-    my @data=();
-    push @data, $self->satellites;
-    $self->{"reported"}=scalar(@data);
-  }
+  $self->{"reported"}=scalar(@{$self->satellites})
+    unless defined $self->{"reported"};
   return $self->{"reported"};
 }
 
@@ -120,11 +123,8 @@ Count of satellites used in calculation
 
 sub used {
   my $self=shift;
-  unless (defined($self->{"used"})) {
-    my @data=();
-    push @data, grep {$_->{"used"}} $self->satellites;
-    $self->{"used"}=scalar(@data);
-  }
+  $self->{"used"}=scalar(@{[grep {$_->{"used"}} $self->satellites]})
+    unless defined $self->{"used"};
   return $self->{"used"};
 }
 
@@ -172,28 +172,29 @@ Log on RT and Send to gpsd-dev email list
 
 =head1 SUPPORT
 
+DavisNetworks.com supports all Perl applications including this package.
+
 Try gpsd-dev email list
 
 =head1 AUTHOR
 
-    Michael R. Davis
-    CPAN ID: MRDVT
-    STOP, LLC
-    domain=>michaelrdavis,tld=>com,account=>perl
-    http://www.stopllc.com/
+  Michael R. Davis
+  CPAN ID: MRDVT
+  STOP, LLC
+  domain=>michaelrdavis,tld=>com,account=>perl
+  http://www.stopllc.com/
 
 =head1 COPYRIGHT
 
 This program is free software licensed under the...
 
-	The BSD License
+  The BSD License
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+The full text of the license can be found in the LICENSE file included with this module.
 
 =head1 SEE ALSO
 
-L<Net::GPSD3>
+L<Net::GPSD3>, L<DateTime>, L<Net::GPSD3::Return::Unknown>
 
 =cut
 
