@@ -1,10 +1,10 @@
 package Net::GPSD3::Return::TPV;
 use strict;
 use warnings;
-use base qw{Net::GPSD3::Return::Unknown};
+use base qw{Net::GPSD3::Return::Unknown::Timestamp};
 use GPS::Point;
 
-our $VERSION='0.08';
+our $VERSION='0.12';
 
 =head1 NAME
 
@@ -20,6 +20,8 @@ Provides a Perl object interface to the Time-Velocity-Position (TVP) object retu
 
 Example JSON objects:
 
+=head3 Protocol 3.1 Versions
+
   {
     "class":"TPV",
     "tag":"MID2",
@@ -48,6 +50,27 @@ Example JSON objects:
     "mode":3
   }
 
+=head3 Protocol 3.4 Version
+
+  {
+    "class":"TPV",
+    "tag":"0x0106",
+    "device":"/dev/cuaU0",
+    "time":"2011-03-20T06:51:59.12Z",
+    "ept":0.005,
+    "lat":37.371427205,
+    "lon":-122.015179890,
+    "alt":25.789,
+    "epx":1.926,
+    "epy":1.808,
+    "epv":6.497,
+    "track":0.0000,
+    "speed":0.000,
+    "climb":0.000,
+    "eps":3.85,
+    "mode":3
+  }
+
 =head1 METHODS PROPERTIES
 
 =head2 class
@@ -68,7 +91,7 @@ Name of originating device.
 
 =cut
 
-sub device {&_define(shift->{"device"})};
+sub device {shift->{"device"}};
 
 =head2 tag
 
@@ -76,7 +99,7 @@ Type tag associated with this GPS sentence; from an NMEA device this is just the
 
 =cut
 
-sub tag {&_define(shift->{"tag"})};
+sub tag {shift->{"tag"}};
 
 =head2 mode
 
@@ -84,40 +107,31 @@ NMEA mode: %d, 0=no mode value yet seen, 1=no fix, 2=2D, 3=3D.
 
 =cut
 
-sub mode {&_define(shift->{"mode"})};
+sub mode {shift->{"mode"}};
 
 =head2 time
 
-Seconds since the Unix epoch, UTC. May have a fractional part of up to .01sec precision.
+Seconds since the Unix epoch, UTC.  The value may have a fractional part of up to .01sec precision.
 
-=cut
+Note: In 2.96 (protocol 3.4) the TPV->time format changed from unix epoch to W3C, but this method hides that from the user.
 
-sub time {&_define(shift->{"time"})};
+=head2 timestamp
+
+W3C formated timestamp value either directly from the protocol >= 3.4 or calculated < 3.4.  The value may have a fractional part of up to .01sec precision.
+
+Note: I expect that in protocol 3.5 the value will be passed directly as TPV->timestamp
 
 =head2 datetime
 
 Returns a L<DateTime> object
 
-=cut
-
-sub datetime {shift->point->datetime};
-
-=head2 strftime
-
-=cut
-
-sub strftime {
-  my $self=shift;
-  return $self->datetime->strftime($self->parent->strftime);
-}
-
 =head2 lat
 
 Latitude in degrees: +/- signifies West/East
 
 =cut
 
-sub lat {&_define(shift->{"lat"})};
+sub lat {shift->{"lat"}};
 
 =head2 lon
 
@@ -125,7 +139,7 @@ Longitude in degrees: +/- signifies North/South.
 
 =cut
 
-sub lon {&_define(shift->{"lon"})};
+sub lon {shift->{"lon"}};
 
 =head2 alt
 
@@ -133,7 +147,7 @@ Altitude in meters.
 
 =cut
 
-sub alt {&_define(shift->{"alt"})};
+sub alt {shift->{"alt"}};
 
 =head2 speed
 
@@ -141,15 +155,15 @@ Speed over ground, meters per second.
 
 =cut
 
-sub speed {&_define(shift->{"speed"})};
+sub speed {shift->{"speed"}};
 
 =head2 track
 
-Course over ground, degreesfrom true north.
+Course over ground, degrees from true north.
 
 =cut
 
-sub track {&_define(shift->{"track"})};
+sub track {shift->{"track"}};
 
 =head2 climb
 
@@ -157,7 +171,7 @@ Climb (postive) or sink (negative) rate, meters per second.
 
 =cut
 
-sub climb {&_define(shift->{"climb"})};
+sub climb {shift->{"climb"}};
 
 =head2 ept
 
@@ -165,13 +179,13 @@ Estimated timestamp error (%f, seconds, 95% confidence).
 
 =cut
 
-sub ept {&_define(shift->{"ept"})};
+sub ept {shift->{"ept"}};
 
 =head2 epx
 
 =cut
 
-sub epx {&_define(shift->{"epx"})};
+sub epx {shift->{"epx"}};
 
 =head2 epy
 
@@ -179,7 +193,7 @@ Latitude error estimate in meters, 95% confidence.
 
 =cut
 
-sub epy {&_define(shift->{"epy"})};
+sub epy {shift->{"epy"}};
 
 =head2 epv
 
@@ -187,7 +201,7 @@ Estimated vertical error in meters, 95% confidence.
 
 =cut
 
-sub epv {&_define(shift->{"epv"})};
+sub epv {shift->{"epv"}};
 
 =head2 eps
 
@@ -195,7 +209,7 @@ Speed error estimate in meters/sec, 95% confifdence.
 
 =cut
 
-sub eps {&_define(shift->{"eps"})};
+sub eps {shift->{"eps"}};
 
 =head2 epd
 
@@ -203,7 +217,7 @@ Direction error estinmate in degrees, 95% confifdence.
 
 =cut
 
-sub epd {&_define(shift->{"epd"})};
+sub epd {shift->{"epd"}};
 
 =head2 epc
 
@@ -211,13 +225,13 @@ Climb/sink error estinmate in meters/sec, 95% confifdence.
 
 =cut
 
-sub epc {&_define(shift->{"epc"})};
+sub epc {shift->{"epc"}};
 
 =head1 METHODS VALUE ADDED
 
 =head2 point
 
-Returns a GPS::Point Object
+Returns a L<GPS::Point> Object
 
 =cut
 
@@ -225,7 +239,9 @@ sub point {
   my $self=shift;
   unless (defined($self->{"point"})) {
     $self->{"point"}=GPS::Point->new(
-         time        => $self->time,    #float seconds from the unix epoch
+         time        => $self->datetime->hires_epoch, #float seconds from the unix epoch
+         timestamp   => $self->timestamp,             #not yet supported but I'm planning it
+         datetime    => $self->datetime,              #not yet supported but I'm planning it
          lat         => $self->lat,     #signed degrees
          lon         => $self->lon,     #signed degrees
          alt         => $self->alt,     #meters above the WGS-84 ellipsoid
@@ -245,21 +261,14 @@ sub point {
   return $self->{"point"};
 }
 
-=head2 _define
-
-=cut
-
-sub _define {
-  my $x=shift;
-  return defined($x) ? $x : '';
-}
-
 =head1 BUGS
 
 Log on RT and Send to gpsd-dev email list
 
 =head1 SUPPORT
 
+DavisNetworks.com supports all Perl applications including this package.
+
 Try gpsd-dev email list
 
 =head1 AUTHOR
@@ -276,8 +285,7 @@ This program is free software licensed under the...
 
   The BSD License
 
-The full text of the license can be found in the
-LICENSE file included with this module.
+The full text of the license can be found in the LICENSE file included with this module.
 
 =head1 SEE ALSO
 
